%
%  Explore map tracker
%
%  This script tracks newly scanned planets with the add-on ExploreMap.
%  With ExploreMap players receive each turn a new XYplan.dat storing old and new planets.
%  New planets occur based on the scanner settings in ExploreMap and can be tricky to follow.
%  The script verifies for each planet if a special property-tag from a former turn exists.
%  If not (this means the planet was detected in the current turn) explmap adds a marker (green cactus)
%  to the starmap for at least one turn.
%  Additionally, a message box will inform the player how many new planets have been scanned.
%
%  18/Nov/2006: Tom Wuerzer
%  10/Apr/2015: tweaked for inclusion in PCC2 plugin library
%

Print "[explmap.q 10/Apr/2015]"

CreatePlanetProperty explmap.seen

Sub explmap
  Local new = 0, t = Turn+1
  Local old = CountPlanets(Not IsEmpty(explmap.seen))
  If old Then
    % I have already seen some planets. What I see now is new.
    ForEach Planet Do
      If IsEmpty(explmap.seen) Then
        NewMarker Planet.loc.x,Planet.loc.y, 7, 5, "", 0, t
	explmap.seen := 1
        new := new + 1
      EndIf
    Next
    If new > 0 then
      MessageBox "Our scanners picked up " & new & " new planets.", "Exploremap Scanner: New Planets!"
    EndIf
  Else
    % I have not seen anything. Just set markers.
    ForEach Planet Do explmap.seen := 1
  EndIf
EndSub

On Load Do Explmap

